@@ -16,7 +16,7 @@ import re
 def parse_arguments():
     parser = ArgumentParser(
         description="Utility to manipulate compilation databases.",
-        usage="./compile-commands.py --dir=DIR",
+        usage="compile-commands --file=FILE",
         formatter_class=RawTextHelpFormatter,
     )
 
@@ -231,9 +231,8 @@ def to_gcc(data):
 
 
 def run(args, index, total, quiet):
-    print("[{}/{}]".format(index + 1, total))
-    if quiet:
-        args += " --quiet"
+    if not quiet:
+        print("[{}/{}]".format(index + 1, total))
     Popen(args, shell=True).wait()
 
 
@@ -302,9 +301,6 @@ def main():
     elif args.gcc:
         data = to_gcc(data)
 
-    if args.run:
-        execute(data, args.threads, args.quiet)
-
     if not args.allow_duplicates:
         data = [dict(t) for t in {tuple(d.items()) for d in data}]
 
@@ -323,6 +319,9 @@ def main():
             )
         )
 
+    if args.run:
+        execute(data, args.threads, args.quiet)
+
 
 if __name__ == "__main__":
     main()
